﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Microsoft.Win32;
using System.Windows.Shell;

namespace WpfWin7TaskBar
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(MainWindow_Loaded);
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            CreateJumpList();

            string[] args = System.Environment.GetCommandLineArgs();

            if (args.Length > 1)
                PlayMediaSource(args[1]);
        }

        private void OpenMediaSource(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            dialog.Title = "Select media file";
            dialog.Filter = "Avi & Wmv|*.avi;*.wmv";

            if ((bool)dialog.ShowDialog())
            {
                PlayMediaSource(dialog.FileName);
            }
        }

        private void PlayCommand_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            PerformPlay();
        }

        private void StopCommand_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            _mediaPlayer.Stop();
            TaskbarItemInfo.Overlay = null;
        }

        private void PauseCommand_Executed(object sender, ExecutedRoutedEventArgs e)
        {
            _mediaPlayer.Pause();
            TaskbarItemInfo.Overlay = (ImageSource)FindResource("PauseImage");
        }

        private void Command_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            e.CanExecute = _mediaPlayer.Source != null;
        }

        private void PlayMediaSource(string filePath)
        {
            _mediaPlayer.Source = new Uri(filePath, UriKind.RelativeOrAbsolute);
            PerformPlay();
        }

        private void PerformPlay()
        {
            _mediaPlayer.Play();
            TaskbarItemInfo.Overlay = (ImageSource)FindResource("PlayImage");
        }

        private void CreateJumpList()
        {
            JumpList jumpList = new JumpList();
            JumpList.SetJumpList(Application.Current, jumpList);

            JumpPath jumpPath = new JumpPath();
            jumpPath.Path = @"C:\Users\Public\Videos\Sample Videos\Wildlife.wmv";
            jumpList.JumpItems.Add(jumpPath);

            JumpTask jumpTask = new JumpTask();
            jumpTask.Title = "Notepad";
            jumpTask.Description = "JumpTask to open Notepad";
            jumpTask.ApplicationPath = @"%windir%\system32\notepad.exe";
            jumpTask.IconResourcePath = @"%windir%\system32\notepad.exe";
            jumpTask.IconResourceIndex = 0;
            jumpList.JumpItems.Add(jumpTask);

            jumpList.Apply();
        }
    }
}
